
#////////////////////////////////////////////////////////////////////////////
# Data Extraction
#////////////////////////////////////////////////////////////////////////////
# Point at the directory where the odb file is
os.chdir(directory+extension+jobFileName)

# Open the database
o1 = session.openOdb(name = jobFileName, path = jobFileName + '.odb', readOnly=True) # Open the output database :o1
myviewport.setValues(displayedObject=o1) # Put the output in the viewport

# Create folders for extracted values and later for images
extractFolder='/Extracted_Data/'
if not os.path.exists(directory+extension+jobFileName+extractFolder):
	os.makedirs(directory+extension+jobFileName+extractFolder)
	
# Open the odb file
odb=session.odbs[jobFileName +'.odb']

# Create a global co-ord system
odb.rootAssembly.DatumCsysByThreePoints(name='CSYS-1', 
    coordSysType=CARTESIAN, origin=(0.0, 0.0, 0.0), point1=(1.0, 0.0, 0.0), 
    point2=(0.0, 1.0, 0.0))

if outputGlobalCoords:	
	dtm = odb.rootAssembly.datumCsyses['CSYS-1']
	session.viewports['Pulse Model 2D'].odbDisplay.basicOptions.setValues(
		transformationType=USER_SPECIFIED, datumCsys=dtm)
	
# Check to see if the simulation was completed
nsteps = len(odb.steps['Impact'].frames) #Count the number of frames
print 'For '+jobFileName+ ' the number of steps is '+str(nsteps)+'\n'+'   '	

#--------------------------------------------------------------------
# Write the simulation configuration to file
configFilePath = directory+extension+jobFileName+extractFolder+jobFileName+'_SimConfig.txt'
simConfigFile = open(configFilePath,'w')

simConfigFile.write('SIMULATION PARAMETERS\n')
simConfigFile.write('{0:10} {1:10} {2:10}'.format('Ttot','Tsol','Tout')+'\n')
simConfigFile.write('{0:<10.3e} {1:<10.3e} {2:<10.3e}'.format(
	totalSimTime,solveStep,outputStep)+'\n')
simConfigFile.write('{0:10} {1:10} {2:10} {3:10}'.format('Ftot','Ftst','Fwvg','Fblank')+'\n')
simConfigFile.write('{0:<10.3e} {1:<10.3e} {2:<10.3e} {3:<10.3e}'.format(
	totalOutputSteps,specOutputFrames,guideOutputFrames,blankFrames)+'\n')
simConfigFile.write('{0:10} {1:10} {2:10} '.format('BetaDamp','BVisLDmp','BVisQDmp')+'\n')
simConfigFile.write('{0:<10.3e} {1:<10.3e} {2:<10.3e}'.format(
	betaDamping,bVisLDamp,bVisQDamp)+'\n')
simConfigFile.write('\n')

simConfigFile.write('SPECIMEN CONFIGURATION\n')
simConfigFile.write('{0:10} {1:10} {2:10} {3:10}'.format(
	'S_elem','S_leng','S_height','S_thick')+'\n')
simConfigFile.write('{0:<10.3e} {1:<10.3e} {2:<10.3e} {3:<10.3e}'.format(
	specElemSize,specLength,specHeight,specThick)+'\n')
simConfigFile.write('{0:10} {1:10} {2:10} {3:10} {4:10} {5:10}'.format(
	'S_Rho','S_E11','S_N12','S_E22','S_G12','S_Ang')+'\n')
simConfigFile.write('{0:<10.3e} {1:<10.3e} {2:<10.3e} {3:<10.3e} {4:<10.3e} {5:<10.3e}'.format(
	specRho,specE11,specNu12,specE22,specG12,specAngle)+'\n')
simConfigFile.write('\n')

simConfigFile.close()
#--------------------------------------------------------------------
if extractData:
	if nsteps < totalOutputSteps:
		print 'For '+jobFileName+' solveStep is too high'+'\n'+'Extraction not performed'+'\n'+'  '
		failure+=1
	else:
		# Define the file extensione for the reports
		rptExt = '.rpt'	
		
		# Create a display group that only includes the specimen nodes
		leaf_dg = dgo.LeafFromNodeSets(nodeSets='SPECIMENINSTANCE.SET_NODE_SPECIMEN',)
		spec_dg_nodes = session.DisplayGroup(leaf=leaf_dg,name='DisGroup-SpecimenNodes')
		# Create a display group that only includes the specimen elements
		leaf_dg2 = dgo.LeafFromElementSets(elementSets='SPECIMENINSTANCE.SET_ELEMENTS_SPECIMEN',)
		spec_dg_elems = session.DisplayGroup(leaf=leaf_dg2, name='DisGroup-SpecimenElements')

		# Write Abaqus reports
		session.fieldReportOptions.setValues(printMinMax=OFF, printTotal=OFF)

		# Output the node table
		rptName= directory+extension+jobFileName+extractFolder+jobFileName+'_NodeLocs'+rptExt
		if os.path.exists(rptName):
			os.remove(rptName)
		session.writeFieldReport(fileName=rptName, append=OFF, sortItem='Node Label', 
			odb=odb, step=0, frame=1, outputPosition=NODAL,displayGroup=spec_dg_nodes,
			variable=(('COORD', NODAL, ((COMPONENT, 'COOR1'), (COMPONENT, 'COOR2'), )),))
			
		# Create file names for ouput variables	
		rptName_Disp = directory+extension+jobFileName+extractFolder+jobFileName+'_Disp'
		rptName_CZDMG = directory+extension+jobFileName+extractFolder+jobFileName+'_CZDMG'
		rptName_TotEnergy = directory+extension+jobFileName+extractFolder +jobFileName+'_TotEnergy'
		if not extractDispEnerOnly:
			rptName_Accel = directory+extension+jobFileName+extractFolder +jobFileName+'_Accel'
			rptName_Stress = directory+extension+jobFileName+extractFolder +jobFileName+'_Stress'
			rptName_Strain = directory+extension+jobFileName+extractFolder +jobFileName+'_Strain'
		
		#--------------------------------------------------------------------
		# Extract the energy time history for the model
		# If the file exists clear it first so they are not appended to
		rptName = rptName_TotEnergy + rptExt
		if os.path.exists(rptName):
			os.remove(rptName)
		# Export energy time history as XY data:
		session.XYDataFromHistory(name='ENERGY-1', odb=odb, 
			outputVariableName='Artificial strain energy: ALLAE for Whole Model', )
		session.XYDataFromHistory(name='ENERGY-2', odb=odb, 
			outputVariableName='Damage dissipation energy: ALLDMD for Whole Model', )
		session.XYDataFromHistory(name='ENERGY-3', odb=odb, 
			outputVariableName='External work: ALLWK for Whole Model', )
		session.XYDataFromHistory(name='ENERGY-4', odb=odb, 
			outputVariableName='Internal energy: ALLIE for Whole Model', )
		session.XYDataFromHistory(name='ENERGY-5', odb=odb, 
			outputVariableName='Internal work by constraint penalty: ALLCW for Whole Model', )
		session.XYDataFromHistory(name='ENERGY-6', odb=odb, 
			outputVariableName='Internal work by penalty contact: ALLPW for Whole Model', )
		session.XYDataFromHistory(name='ENERGY-7', odb=odb, 
			outputVariableName='Kinetic energy: ALLKE for Whole Model', )
		session.XYDataFromHistory(name='ENERGY-8', odb=odb, 
			outputVariableName='Strain energy: ALLSE for Whole Model', )
		session.XYDataFromHistory(name='ENERGY-9', odb=odb, 
			outputVariableName='Total energy of the output set: ETOTAL for Whole Model', )
		session.XYDataFromHistory(name='ENERGY-10', odb=odb, 
			outputVariableName='Viscous dissipation: ALLVD for Whole Model', )
		x0 = session.xyDataObjects['ENERGY-1']
		x1 = session.xyDataObjects['ENERGY-2']
		x2 = session.xyDataObjects['ENERGY-3']
		x3 = session.xyDataObjects['ENERGY-4']
		x4 = session.xyDataObjects['ENERGY-5']
		x5 = session.xyDataObjects['ENERGY-6']
		x6 = session.xyDataObjects['ENERGY-7']
		x7 = session.xyDataObjects['ENERGY-8']
		x8 = session.xyDataObjects['ENERGY-9']
		x9 = session.xyDataObjects['ENERGY-10']
		session.writeXYReport(fileName=rptName, xyData=(x0, x1, x2, x3, x4, x5, 
			x6, x7, x8, x9 ))
		#--------------------------------------------------------------------

		print '\n'
		for i in range (1, nsteps): # Loop over result steps
			print str(jobFileName)+': extracting frame '+str(i)+'\n'
			
			# Write the nodal displacement data to file
			rptName = rptName_Disp + str(i) + rptExt
			session.writeFieldReport(fileName=rptName, append=OFF, sortItem='Node Label', 
				odb=odb, step=0, frame=i, outputPosition=NODAL, displayGroup=spec_dg_nodes,
				variable=(('UT', NODAL, ((COMPONENT, 'U1'), (COMPONENT, 'U2'), )), ))
				
			if not extractDispEnerOnly:
				# Write the nodal acceleration data to file
				rptName = rptName_Accel + str(i) + rptExt
				session.writeFieldReport(fileName=rptName, append=OFF, sortItem='Node Label', 
					odb=odb, step=0, frame=i, outputPosition=NODAL, displayGroup=spec_dg_nodes,
					variable=(('AT', NODAL, ((COMPONENT, 'A1'), (COMPONENT, 'A2'), )), ))
					
				# Write strains to file, interpolate to the nodes
				rptName = rptName_Strain + str(i) + rptExt
				session.writeFieldReport(fileName=rptName, append=OFF, sortItem='Element Label', odb=odb, 
					step=0, frame=i, outputPosition=NODAL, displayGroup=spec_dg_elems,
					variable=(('E', INTEGRATION_POINT, ((COMPONENT, 'E11'), (COMPONENT, 'E22'),
					(COMPONENT, 'E12'), )), ))
						
				# Write stress to file, interpolate to the nodes
				rptName = rptName_Stress + str(i) + rptExt
				session.writeFieldReport(fileName=rptName, append=OFF, sortItem='Element Label', odb=odb, 
					step=0, frame=i, outputPosition=NODAL, displayGroup=spec_dg_elems,
					variable=(('S', INTEGRATION_POINT, ((COMPONENT, 'S11'), (COMPONENT, 'S22'),
					(COMPONENT, 'S12'), )), ))
							
		print '\n'
		print '\n'+'Data extraction complete.' +'\n'+'   '
			
		# Close the database when finished
		session.odbs[jobFileName + '.odb'].close()
		