% Create initialisation parameters data structure for processing FE data
%
% Date - Version - Additions
% 25/03/2020 - Ver1 - First code
% 14/08/2020 - Added simConfig read-in
%
%-------------------------------------------------------------------------%
% Notes:
% N/A
%-------------------------------------------------------------------------%

clc
clear all
close all

%-------------------------------------------------------------------------%
% Paths
%-------------------------------------------------------------------------%
% Define the path for where this initialisation file is saved.

% Specify the base path and sub-folder
basePath = 'E:\experimentalData\ModulusPaper\FE_UD90';
dataFolderName = 'AbaqusToMatlab';

% Define the save path (make the directory if it does not exist)
fprintf('Save the initialisation file to the specified path. \n')
savePath = ([basePath,'\',dataFolderName]);
    if ~exist(savePath,'dir')
        mkdir(savePath);
    end
addpath(savePath);

% Point to where the Abaqus output files are saved
extractedDataDir = 'E:\experimentalData\ModulusPaper\FE_UD90\2D_CFRPPulse_UD90\Extracted_Data';
addpath(extractedDataDir);

%% -----------------------------------------------------------------------%
% Read in SimConfigFile data
fprintf('Creating data structures for processing FE data. \n')

% Define the name of the sim config file
simConfigFileName = '2D_CFRPPulse_UD90_SimConfig.txt';
simConfigFile = ([extractedDataDir,'\',simConfigFileName]);
headerRows = 2;
fHandle = fopen(simConfigFile);
    
timeData = textscan(fHandle,'%f %f %f','headerLines',headerRows);
frameData = textscan(fHandle,'%f %f %f %f','headerLines',headerRows-1);
dampingData = textscan(fHandle,'%f %f %f','headerLines',headerRows-1);

% Time
FE.outputStep = timeData{3}; % 0.5e-6
FE.frameRate = 1/FE.outputStep; % 2e6
FE.specOutputFrames = frameData{1}; % 128
FE.timeVec = FE.outputStep : FE.outputStep : FE.outputStep*FE.specOutputFrames;
FE.timeIndVec = 1 : FE.specOutputFrames;

% Sample
specGeom = textscan(fHandle,'%f %f %f %f','headerLines',headerRows);
specMat = textscan(fHandle,'%f %f %f %f %f %f','headerLines',headerRows-1);
FE.specElemSize = specGeom{1}; % 0.25e-3
FE.specLength = specGeom{2}; % 70e-3
FE.specHeight = specGeom{3}; % 45e-3;
FE.specThick = specGeom{4}; %3e-3

% Pos struct for FE data
% Assumes free-edge, bottom is the origin (not free-edge, centre as in Abaqus). 
FE.pos.x = FE.specElemSize/2 : FE.specElemSize : FE.specLength-FE.specElemSize/2;
FE.pos.y = FE.specElemSize/2 : FE.specElemSize : FE.specHeight-FE.specElemSize/2;
FE.pos.xStep = FE.specElemSize;
FE.pos.yStep = FE.specElemSize;

%% -----------------------------------------------------------------------%
% Save 

% Name of the FE simulation initialisation file
saveFile = 'FESimProcessingParameters_v1.mat';

fprintf('Saving the FE processing parameters file(s). \n')
save(fullfile(savePath,saveFile));
